import 'package:pixelpay_sdk/base/helpers.dart';

class Response {
  /// HTTP response status code
  int? _status;

  /// Response status success
  bool? success;

  /// Response friendly message
  String? message;

  /// Response 'action to' format
  String? action;

  /// Response data payload
  Map<String, dynamic>? data;

  /// Response input validation felds errors
  Map<String, List<String>>? errors;

  /// Contructor
  Response();

  Response fromResponse(Response response) {    
    _status = response.getStatus();
    success = response.success;
    message = response.message;
    action = response.action;
    data = response.data;
    errors = response.errors;

    return this;
  }

  /// Define HTTP status code response
  ///
  /// @param status
  void setStatus(int status) {
    _status = status;
  }

  /// Get HTTP status code
  ///
  /// @return
  int? getStatus() {
    return _status;
  }

  /// Verify input has error
  ///
  /// @param key
  /// @return
  bool inputHasError(String key) {
    if (errors == null) {
      return false;
    }

    return errors?.containsKey(key) ?? false;
  }

  /// Get data payload by key
  ///
  /// @param key
  /// @return
  dynamic getData(String key) {
    if (data == null) {
      return null;
    }

    return data![key];
  }

  /// Serialize object to JSON string
  ///
  /// @return
  String toJson() {
    final val = <String, dynamic>{};

    void writeNotNull(String key, dynamic value) {
      if (value != null) {
        val[key] = value;
      }
    }

    writeNotNull('success', success);
    writeNotNull('message', message);
    writeNotNull('action', action);
    writeNotNull('data', data);
    writeNotNull('errors', errors);

    return Helpers.objectToJson(val);
  }

  /// Factory from JSON
  factory Response.fromJson(String data) {
    final json = Helpers.jsonToMap(data);

    return Response()
      ..success = json['success'] as bool?
      ..message = json['message'] as String?
      ..action = json['action'] as String?
      ..data = json['data'] as Map<String, dynamic>?
      ..errors = (json['errors'] as Map<String, dynamic>?)?.map(
        (k, e) =>
            MapEntry(k, (e as List<dynamic>).map((e) => e as String).toList()),
      );
  }
}
