import 'package:pixelpay_sdk/base/response.dart';
import 'package:pixelpay_sdk/responses/error_response.dart';
import 'package:pixelpay_sdk/responses/payment_declined_response.dart';
import 'package:pixelpay_sdk/responses/success_response.dart';
import 'package:pixelpay_sdk/responses/timeout_response.dart';

class TransactionResult {
	/// Transaction response type
	String? transaction_type;

	/// Approved amount on capture/sale
	double? transaction_approved_amount;

	/// Initial or registered transaction amount
	double? transaction_amount;

	/// Transaction AUTH reference code
	String? transaction_auth;

	/// Transacction network terminal ID
	String? transaction_terminal;

	/// Transaction network merchant ID
	String? transaction_merchant;

	/// CVV2 result response code
	String? response_cvn;

	/// Address verification code response
	String? response_avs;

	/// CAVV network evaluation result code
	String? response_cavv;

	/// Transaction identifier
	String? transaction_id;

	/// Transaction STAN, proccesor transacction identifier or transaction reference
	String? transaction_reference;

	/// Transaction result time
	String? transaction_time;

	/// Transaction result date
	String? transaction_date;

	/// Response is financial approved
	bool? response_approved;

	/// Response fatal not completed or excecution interrupted
	bool? response_incomplete;

	/// Proccesor response code
	String? response_code;

	/// Network response time
	String? response_time;

	/// Proccesor response message
	String? response_reason;

	/// Payment unique identifier
	String? payment_uuid;

	/// Payment integrity validation hash
	String? payment_hash;

	/// Validate if response type is valid for parse
	/// 
	/// @param response
	/// @return
	static bool validateResponse(Response response) {
		return response is SuccessResponse 
			|| response is PaymentDeclinedResponse 
			|| response is ErrorResponse
			|| response is TimeoutResponse;
	}

	/// Convert success response to transaction entity
	/// 
	/// @param response
	/// @return
	static TransactionResult fromResponse(Response response) {
		return TransactionResult()
      ..transaction_type = response.data!['transaction_type'] as String?
      ..transaction_approved_amount = response.data!['transaction_approved_amount'] as double?
      ..transaction_amount = response.data!['transaction_amount'] as double?
      ..transaction_auth = response.data!['transaction_auth'] as String?
      ..transaction_terminal = response.data!['transaction_terminal'] as String?
      ..transaction_merchant = response.data!['transaction_merchant'] as String?
      ..response_cvn = response.data!['response_cvn'] as String?
      ..response_avs = response.data!['response_avs'] as String?
      ..response_cavv = response.data!['response_cavv'] as String?
      ..transaction_id = response.data!['transaction_id'] as String?
      ..transaction_reference = response.data!['transaction_reference'] as String?
      ..transaction_time = response.data!['transaction_time'] as String?
      ..transaction_date = response.data!['transaction_date'] as String?
      ..response_approved = response.data!['response_approved'] as bool?
      ..response_incomplete = response.data!['response_incomplete'] as bool?
      ..response_code = response.data!['response_code'] as String?
      ..response_time = response.data!['response_time'] as String?
      ..response_reason = response.data!['response_reason'] as String?
      ..payment_uuid = response.data!['payment_uuid'] as String?
      ..payment_hash = response.data!['payment_hash'] as String?;
	}
}
