import 'package:pixelpay_sdk/models/item.dart';

class Order {
  /// Order ID
  String? id;

  /// Order currency code alpha-3
  String? currency;

  /// Order total amount
  double? amount;

  /// Order total tax amount
  double? tax_amount;

  /// Order total shipping amount
  double? shipping_amount;

  /// Order summary of items or products
  List<Item>? content;

  /// Order extra properties
  Map<String, String>? extras;

  /// Order note or aditional instructions
  String? note;

  /// Order calback webhook URL
  String? callback_url;

  /// Order customer name
  String? customer_name;

  /// Order customer email
  String? customer_email;

  /// Add item to content list of products/items
  ///
  /// @param item
  /// @return
  Order addItem(Item item) {
    content ??= <Item>[];

    content!.add(item);
    totalize();

    return this;
  }

  /// Add extra property to order
  ///
  /// @param key
  /// @param value
  /// @return
  Order addExtra(String key, dynamic value) {
    extras ??= {};

    String parsedvalue = value.toString();
    extras![key] = parsedvalue;

    return this;
  }

  /// Totalize order amounts and items
  ///
  /// @return
  Order totalize() {
    if (content != null && content!.isNotEmpty) {
      amount = 0.00;
      tax_amount = 0.00;

      for (Item item in content!) {
        item.totalize();

        amount = amount! + item.total;
        tax_amount = tax_amount! + (item.tax * item.qty);
      }
    }

    return this;
  }
}
