import 'package:pixelpay_sdk/base/helpers.dart';
import 'package:pixelpay_sdk/resources/environment.dart';

class Settings {
  /// Merchant API auth key
  String? auth_key;

  /// Merchant API auth hash (MD5 of secret key)
  String? auth_hash;

  /// Merchant API platform auth user (SHA-512 of user email)
  String? auth_user;

  /// Merchant API endpoint URL
  String endpoint = "https://pixelpay.app";

  /// Merchant API environment
  String? environment;

  /// Settings response messages language
  String? lang;

  /// SDK identifier
  String? sdk;

  /// Setup API endpoint URL
  ///
  /// @param endpoint
  void setupEndpoint(String endpoint) {
    this.endpoint = endpoint;
  }

  /// Setup API credentials
  ///
  /// @param key
  /// @param hash
  void setupCredentials(String key, String hash) {
    auth_key = key;
    auth_hash = hash;
  }

  /// Setup API platform user
  ///
  /// @param hash
  void setupPlatformUser(String hash) {
    auth_user = hash;
  }

  /// Setup API environment
  ///
  /// @param env
  void setupEnvironment(String env) {
    environment = env;
  }

  /// Setup defaults to Sandbox credentials
  void setupSandbox() {
    endpoint = "https://pixel-pay.com";
    auth_key = "1234567890";
    auth_hash = Helpers.hash("MD5",
        "@s4ndb0x-abcd-1234-n1l4-p1x3l"); // MD5: @s4ndb0x-abcd-1234-n1l4-p1x3l

    environment = Environment.SANDBOX;
  }

  /// Setup response messages language
  ///
  /// @param lang
  void setupLanguage(String lang) {
    this.lang = lang;
  }

  /// Serialize object to JSON string
  ///
  /// @return
  String toJson() {
    final val = <String, dynamic>{};

    void writeNotNull(String key, dynamic value) {
      if (value != null) {
        val[key] = value;
      }
    }

    writeNotNull('auth_key', auth_key);
    writeNotNull('auth_hash', auth_hash);
    writeNotNull('auth_user', auth_user);
    writeNotNull('environment', environment);
    writeNotNull('lang', lang);
    writeNotNull('sdk', sdk);

    val['endpoint'] = endpoint;

    return Helpers.objectToJson(val);
  }
}
