import 'package:pixelpay_sdk/base/helpers.dart';
import 'package:pixelpay_sdk/base/request_behaviour.dart';
import 'package:pixelpay_sdk/models/billing.dart';
import 'package:pixelpay_sdk/models/card.dart';
import 'package:pixelpay_sdk/models/order.dart';

class PaymentTransaction extends RequestBehaviour {
	/// Payment UUID
	String? payment_uuid;

	/// Tokenized card identifier (T-* format)
	String? card_token;

	/// Card number or PAN
	String? card_number;

	/// Card security code
	String? card_cvv;

	/// Card expire year/month date (YYMM)
	String? card_expire;

	/// Cardholder name
	String? card_holder;

	/// Customer billing address
	String? billing_address;

	/// Customer billing country alpha-2 code (ISO 3166-1)
	String? billing_country;

	/// Customer billing state alpha code (ISO 3166-2)
	String? billing_state;

	/// Customer billing city
	String? billing_city;

	/// Customer billing postal code
	String? billing_zip;

	/// Customer billing phone
	String? billing_phone;

	/// Order customer name
	String? customer_name;

	/// Order customer email
	String? customer_email;

	/// Order customer device fingerprint
	String? customer_fingerprint;

	/// Order ID
	String? order_id;

	/// Order currency code alpha-3
	String? order_currency;

	/// Order total amount
	String? order_amount;

	/// Order total tax amount
	String? order_tax_amount;

	/// Order total shipping amount
	String? order_shipping_amount;

	/// Order summary of items or products
	List<dynamic>? order_content;

	/// Order extra properties
	Map<String, String>? order_extras;

	/// Order note or aditional instructions
	String? order_note;

	/// Order calback webhook URL
	String? order_callback;

	/// Activate authentication request (3DS/EMV)
	bool authentication_request = false;

	/// Authentication transaction identifier
	String? authentication_identifier;

	/// Associate and mapping Card model properties to transaction
	/// 
	/// @param card
	void setCard(Card card) {
		card_number = Helpers.trimValue(card.number);
		card_cvv = card.cvv2;
		card_expire = card.getExpireFormat();
		card_holder = Helpers.trimValue(card.cardholder);
	}

	/// Associate and mapping CardToken model properties to transaction
	/// 
	/// @param token
	void setCardToken(String token) {
		card_token = token;
	}

	/// Associate and mapping Billing model properties to transaction
	/// 
	/// @param billing
	void setBilling(Billing billing) {
		billing_address = Helpers.trimValue(billing.address);
		billing_country = billing.country;
		billing_state = billing.state;
		billing_city = Helpers.trimValue(billing.city);
		billing_zip = billing.zip;
		billing_phone = billing.phone;
	}

	/// Associate and mapping Order model properties to transaction
	/// 
	/// @param order
	void setOrder(Order order) {
		order_id = order.id;
		order_currency = order.currency;
		order_amount = Helpers.parseAmount(order.amount);
		order_tax_amount = Helpers.parseAmount(order.tax_amount);
		order_shipping_amount = Helpers.parseAmount(order.shipping_amount);

    if (order.content != null) {
		  order_content = order.content!.isEmpty ? null : order.content!.toList();
    }

    if (order.extras != null) {
		  order_extras = order.extras!.isEmpty ? null : order.extras;
    }
    
		order_note = Helpers.trimValue(order.note);
		order_callback = order.callback_url;

		customer_name = Helpers.trimValue(order.customer_name);
		customer_email = order.customer_email;
	}

	/// Enable 3DS/EMV authentication request
	void withAuthenticationRequest() {
		authentication_request = true;
	}
}
