import 'dart:convert';

import 'package:flutter/services.dart';

class Locations {
	/// Countries resource repository
	static Map<String, String> _countriesRepository = Map();

	/// States resource repository
	static Map<String, dynamic> _statesRepository = Map();

	/// Verify respository is available
	static void _checkRepository() async {
		if (Locations._countriesRepository.isEmpty || Locations._statesRepository.isEmpty) {
      String countries = await rootBundle.loadString('assets/countries.json', cache: true);
      String states = await rootBundle.loadString('assets/states.json', cache: true);

      _countriesRepository = jsonDecode(countries);
      _statesRepository = jsonDecode(states);
		}
	}

	/// Return a list of countries
	/// 
	/// @return
	static Map<String, String> countriesList() {
		_checkRepository();

		return _countriesRepository;
	}

	/// Get states list by country ISO code
	/// 
	/// @param country_code
	/// @return
	static Map<String, String> statesList(String country_code) {
		_checkRepository();

    if (!_statesRepository.containsKey(country_code)) {
      return {};
    }

		return _statesRepository[country_code];
	}
}
