import 'package:pixelpay_sdk/base/helpers.dart';
import 'package:pixelpay_sdk/base/response.dart';
import 'package:pixelpay_sdk/base/service_behaviour.dart';
import 'package:pixelpay_sdk/models/settings.dart';
import 'package:pixelpay_sdk/requests/auth_transaction.dart';
import 'package:pixelpay_sdk/requests/capture_transaction.dart';
import 'package:pixelpay_sdk/requests/sale_transaction.dart';
import 'package:pixelpay_sdk/requests/status_transaction.dart';
import 'package:pixelpay_sdk/requests/void_transaction.dart';

class Transaction extends ServiceBehaviour {
  /// Initialize service
  Transaction(Settings settings) : super(settings);

	/// Send and proccesing SALE transaction
	/// 
	/// @param transaction
	/// @return
	/// @throws InvalidCredentialsException
	/// @throws IOException
	Future<Response?> doSale(SaleTransaction transaction) {
    return send('transactionDoSale', {
      'request': transaction.toJson(),
      'settings': settings.toJson()
    });
	}

	/// Send and proccesing AUTH transaction
	/// 
	/// @param transaction
	/// @return
	/// @throws InvalidCredentialsException
	/// @throws IOException
	Future<Response?> doAuth(AuthTransaction transaction) async {
		return send('transactionDoAuth', {
      'request': transaction.toJson(),
      'settings': settings.toJson()
    });
	}

	/// Send and proccesing CAPTURE transaction
	/// 
	/// @param transaction
	/// @return
	/// @throws InvalidCredentialsException
	/// @throws IOException
	Future<Response?> doCapture(CaptureTransaction transaction) async {
		return send('transactionDoCapture', {
      'request': transaction.toJson(),
      'settings': settings.toJson()
    });
	}

	/// Send and proccesing VOID transaction
	/// 
	/// @param transaction
	/// @return
	/// @throws InvalidCredentialsException
	/// @throws IOException
	Future<Response?> doVoid(VoidTransaction transaction) async {
		return send('transactionDoVoid', {
      'request': transaction.toJson(),
      'settings': settings.toJson()
    });
	}

	/// Verify transaction status
	/// 
	/// @param transaction
	/// @return
	/// @throws InvalidCredentialsException
	/// @throws IOException
	Future<Response?> getStatus(StatusTransaction transaction) async {
		return send('transactionGetStatus', {
      'request': transaction.toJson(),
      'settings': settings.toJson()
    });
	}

	/// Verify a payment hash and returns true if payment response is not modified
	/// 
	/// @param hash
	/// @param order_id
	/// @param secret
	/// @return
	bool verifyPaymentHash(String hash, String order_id, String secret) {
		return hash == Helpers.hash("MD5", [order_id, settings.auth_key, secret].join('|'));
	}
}