import 'package:flutter_test/flutter_test.dart';
import 'package:pixelpay_sdk/models/item.dart';
import 'package:pixelpay_sdk/models/order.dart';

void main() {
  test('testOrderIsEmpty', () {
    final order = Order();

		expect(order.id, null);
		expect(order.currency, null);
		expect(order.amount, null);
		expect(order.tax_amount, null);
		expect(order.shipping_amount, null);
		expect(order.content, null);
		expect(order.extras, null);
		expect(order.note, null);
		expect(order.callback_url, null);
		expect(order.customer_name, null);
		expect(order.customer_email, null);
  });

  test('testSetOrder', () {
    final order = Order();

		order.id = "TEST-CASE";
		order.currency = "MXN";
		order.amount = 10.00;
		order.tax_amount = 5.00;
		order.shipping_amount = 5.00;
		order.note = "Nota";
		order.callback_url = "https://www.pixel.hn/es";
		order.customer_name = "Jhon Doe";
		order.customer_email = "jhond@pixel.hn";

		expect(order.id != null, true);
		expect(order.currency != null, true);
		expect(order.amount != null, true);
		expect(order.tax_amount != null, true);
		expect(order.shipping_amount != null, true);
		expect(order.note != null, true);
		expect(order.callback_url != null, true);
		expect(order.customer_name != null, true);
		expect(order.customer_email != null, true);
		expect(order.amount, 10.00);

		order.totalize();

		expect(order.amount, 10.00);
  });

  test('testOrderWithItems', () {
    final order = Order();
		final item = Item();

		item.code = "XCTA-1u";
		item.title = "XCTA-TEST";
		item.price = 5.00;
		item.qty = 5;
		item.tax = 10;

		order.addItem(item);
		order.totalize();

		expect(item.price * item.qty, order.amount);
		expect(item.tax * item.qty, order.tax_amount);
  });

  test('testOrderWithExtras', () {
    final order = Order();
		order.addExtra("id", "123");

		expect(order.extras?.isEmpty, false);
		expect(order.extras?.containsKey('order'), false);
		expect(order.extras?.containsKey('id'), true);
  });
}