import 'package:flutter_test/flutter_test.dart';
import 'package:pixelpay_sdk/models/settings.dart';

void main() {
  test('testSetupMerchant', () {
    final merchant = Settings();
		const endpoint = "https://pixel-pay.com";
    
		expect(merchant.endpoint, "https://pixelpay.app");

		merchant.setupEndpoint(endpoint);
		expect(merchant.endpoint, "https://pixel-pay.com");
  });

  test('testSetupCredentials', () {
    final merchant = Settings();
		const merchant_key = "2212294583";
		const merchant_hash = "c7dd7a6cf3e47417edb3456c22218a5d";

		expect(merchant.auth_key, null);
		expect(merchant.auth_hash, null);

		merchant.setupCredentials(merchant_key, merchant_hash);

		expect(merchant.auth_key != null, true);
		expect(merchant.auth_hash != null, true);
  });

  test('testSetupPlatformUser', () {
    final merchant = Settings();
		const merchant_user = "c218697e71f1c8bb9efee480a9e3b90a930d8cfa662db3e3b78879ea38363dad7eefb9ebe8db582ba35cc46fa7d80baedf778195faecaea66d9222036793c937";

		expect(merchant.auth_user, null);

		merchant.setupPlatformUser(merchant_user);
		expect(merchant.auth_user != null, true);
  });

  test('testSetupEnvironment', () {
    final merchant = Settings();
		expect(merchant.environment, null);

		merchant.setupEnvironment("test");
		expect(merchant.environment != null, true);
		expect(merchant.environment, "test");
  });

  test('testSetupSandbox', () {
    final merchant = Settings();
		const sandbox_endpoint = "https://pixel-pay.com";
		const sandbox_auth = "1234567890";
		const sandbox_hash = "36cdf8271723276cb6f94904f8bde4b6";
		const sandbox_env = "sandbox";

		expect(merchant.endpoint != sandbox_endpoint, true);
		expect(merchant.auth_key, null);
		expect(merchant.auth_hash, null);
		expect(merchant.environment, null);

		merchant.setupSandbox();
		expect(merchant.endpoint, sandbox_endpoint);
		expect(merchant.auth_key, sandbox_auth);
		expect(merchant.auth_hash, sandbox_hash);
		expect(merchant.environment, sandbox_env);
  });

  test('testJSONParse', () {
    final merchant = Settings();

    expect(merchant.toJson(), '{"endpoint":"https://pixelpay.app"}');

    merchant.setupSandbox();
    expect(merchant.toJson(), '{"auth_key":"1234567890","auth_hash":"36cdf8271723276cb6f94904f8bde4b6","environment":"sandbox","endpoint":"https://pixel-pay.com"}');
  });
}