import 'dart:math';
import 'package:flutter_test/flutter_test.dart';
import 'package:pixelpay_sdk/models/billing.dart';
import 'package:pixelpay_sdk/models/card.dart';
import 'package:pixelpay_sdk/models/item.dart';
import 'package:pixelpay_sdk/models/order.dart';
import 'package:pixelpay_sdk/models/settings.dart';
import 'package:pixelpay_sdk/requests/sale_transaction.dart';
import 'package:pixelpay_sdk/responses/success_response.dart';
import 'package:pixelpay_sdk/services/transaction.dart';

final _rnd = Random();

const _chars = 'AaBbCcDdEeFfGgHhIiJjKkLlMmNnOoPpQqRrSsTtUuVvWwXxYyZz1234567890';

String getRandomString(int length) => String.fromCharCodes(Iterable.generate(
    length, (_) => _chars.codeUnitAt(_rnd.nextInt(_chars.length))));

Billing getBillingModel() {
  final billing = Billing();
  billing.address = "Ave Circunvalacion";
  billing.country = "HN";
  billing.state = "HN-CR";
  billing.city = "San Pedro Sula";
  billing.phone = "95852921";

  return billing;
}

Card getCardModel() {
  final card = Card();
  card.number = "4111111111111111";
  card.cvv2 = "009";
  card.expire_month = 12;
  card.expire_year = 2023;
  card.cardholder = "IVAN SUAZO";

  return card;
}

Order getOrderModel(double amount) {
  final item = Item();
  item.code = "00001";
  item.title = "Example product";
  item.price = 1.99;
  item.qty = 2;

  final order = Order();
  order.id = getRandomString(8);
  order.amount = amount;
  order.currency = "HNL";
  order.customer_email = "carlos@pixel.hn";
  order.customer_name = "Carlos Agaton";

  return order;
}

void main() {
  TestWidgetsFlutterBinding.ensureInitialized();

  test('testInvalidCredentials', () async {
    final settings = Settings();
    settings.setupSandbox();
    settings.setupEnvironment('testing');

    final sale = SaleTransaction();
    final service = Transaction(settings);

    final response = await service.doSale(sale);

    expect(response as SuccessResponse, true);
  });

  test('testTokenizationRequest', () {});
}
